@@ -22,6 +22,7 @@ __all__ = [
     'icon',
     'icon_fromfile',
     'row',
+    'file',
 ]
 
 box = app.box
@@ -40,6 +41,7 @@ fns = app.Fns
 icon_fromfile = app.icon_fromfile
 icon = app.icon
 row=app.row
+file=app.file
 
 # v = FnContext()
 
