@@ -30,6 +30,9 @@ class Tabs(_Tabs):
     def boxes(self):
         return self._boxes
 
+    def __iter__(self):
+        return iter(self.boxes)
+
     def __getitem__(self, key: Union[str, int]):
         if isinstance(key, int):
             return self._boxes[key]
